This library is meant to be used to create CanFetch derive macros for the
apecs library and libraries that might light to encapsulate and re-export
the apecs library.
Functions
- derive_
canfetch - Helper to create
CanFetchderive macros with a configurable module prefix. - derive_
trydefault - Helper to create
TryDefaultderive macros with a configurable module prefix.