This library is meant to be used to create CanFetch derive macros for the apecs library and libraries that might light to encapsulate and re-export the apecs library.

Functions

Helper to create CanFetch derive macros with a configurable module prefix.
Helper to create TryDefault derive macros with a configurable module prefix.